@@ -19,7 +19,7 @@ use utils::globs::build_ignore_glob_set;
 use utils::slugs::slugify_paths;
 
 // We want a default base url for tests
-static DEFAULT_BASE_URL: &str = "http://a-website.com";
+const DEFAULT_BASE_URL: &str = "http://a-website.com";
 
 #[derive(Copy, Clone, Debug, PartialEq, Eq, Serialize, Deserialize)]
 #[serde(rename_all = "lowercase")]
@@ -29,6 +29,13 @@ pub enum Mode {
     Check,
 }
 
+#[derive(Copy, Clone, Debug, PartialEq, Eq, Serialize, Deserialize)]
+#[serde(rename_all = "lowercase")]
+pub enum ExcludePaginatedPagesInSitemap {
+    None,
+    All,
+}
+
 #[derive(Clone, Debug, Deserialize)]
 #[serde(default, deny_unknown_fields)]
 pub struct Config {
@@ -102,6 +109,8 @@ pub struct Config {
     pub generate_sitemap: bool,
     /// Enables the generation of robots.txt
     pub generate_robots_txt: bool,
+    /// Whether to exclude paginated pages in sitemap; can take values "none", "all"
+    pub exclude_paginated_pages_in_sitemap: ExcludePaginatedPagesInSitemap,
 }
 
 #[derive(Serialize)]
@@ -123,6 +132,7 @@ pub struct SerializedConfig<'a> {
     search: search::SerializedSearch<'a>,
     generate_sitemap: bool,
     generate_robots_txt: bool,
+    exclude_paginated_pages_in_sitemap: ExcludePaginatedPagesInSitemap,
 }
 
 impl Config {
@@ -176,6 +186,7 @@ impl Config {
 
         // this is the step at which missing extra syntax and highlighting themes are raised as errors
         config.markdown.init_extra_syntaxes_and_highlight_themes(config_dir)?;
+        config.markdown.validate_external_links_class()?;
 
         Ok(config)
     }
@@ -193,6 +204,7 @@ impl Config {
         let trailing_bit = if path.ends_with('/')
             || self.feed_filenames.iter().any(|feed_filename| path.ends_with(feed_filename))
             || path.is_empty()
+            || path.contains("#")
         {
             ""
         } else {
@@ -287,6 +299,10 @@ impl Config {
         self.mode == Mode::Check
     }
 
+    pub fn should_exclude_paginated_pages_in_sitemap(&self) -> bool {
+        self.exclude_paginated_pages_in_sitemap == ExcludePaginatedPagesInSitemap::All
+    }
+
     pub fn enable_serve_mode(&mut self) {
         self.mode = Mode::Serve;
     }
@@ -340,6 +356,7 @@ impl Config {
             search: self.search.serialize(),
             generate_sitemap: self.generate_sitemap,
             generate_robots_txt: self.generate_robots_txt,
+            exclude_paginated_pages_in_sitemap: self.exclude_paginated_pages_in_sitemap,
         }
     }
 }
@@ -405,6 +422,7 @@ impl Default for Config {
             extra: HashMap::new(),
             generate_sitemap: true,
             generate_robots_txt: true,
+            exclude_paginated_pages_in_sitemap: ExcludePaginatedPagesInSitemap::None,
         }
     }
 }
@@ -567,6 +585,13 @@ hello = "world"
         assert_eq!(config.make_permalink("atom.xml"), "http://vincent.is/atom.xml");
     }
 
+    // https://github.com/getzola/zola/issues/2676
+    #[test]
+    fn permalink_with_anchor() {
+        let config = Config { base_url: "http://vincent.is".to_string(), ..Default::default() };
+        assert_eq!(config.make_permalink("/about#me"), "http://vincent.is/about#me");
+    }
+
     #[test]
     fn can_merge_with_theme_data_and_preserve_config_value() {
         let config_str = r#"
@@ -1066,4 +1091,6 @@ base_url = "example.com"
         let config = Config::parse(config).unwrap();
         assert!(config.generate_robots_txt);
     }
+
+    // TODO: add a test for excluding paginated pages
 }
