@@ -1,6 +1,6 @@
 use errors::{anyhow, Context, Result};
 use libs::avif_parse::read_avif;
-use libs::image::ImageReader;
+use libs::image::{ImageDecoder, ImageReader};
 use libs::image::{ImageFormat, ImageResult};
 use libs::svg_metadata::Metadata as SvgMetadata;
 use serde::Serialize;
@@ -9,6 +9,8 @@ use std::fs::File;
 use std::io::BufReader;
 use std::path::Path;
 
+use crate::get_rotated_size;
+
 /// Size and format read cheaply with `image`'s `Reader`.
 #[derive(Debug)]
 pub struct ImageMeta {
@@ -21,7 +23,13 @@ impl ImageMeta {
     pub fn read(path: &Path) -> ImageResult<Self> {
         let reader = ImageReader::open(path).and_then(ImageReader::with_guessed_format)?;
         let format = reader.format();
-        let size = reader.into_dimensions()?;
+        let mut decoder = reader.into_decoder()?;
+        let mut size = decoder.dimensions();
+        let raw_metadata = decoder.exif_metadata()?;
+
+        if let Some((w, h)) = get_rotated_size(size.0, size.1, raw_metadata) {
+            size = (w, h);
+        }
 
         Ok(Self { size, format })
     }
