@@ -36,11 +36,6 @@ pub fn render_feeds(
 ) -> Result<Option<Vec<String>>> {
     let mut pages = all_pages.into_iter().filter(|p| p.meta.date.is_some()).collect::<Vec<_>>();
 
-    // Don't generate a feed if none of the pages has a date
-    if pages.is_empty() {
-        return Ok(None);
-    }
-
     pages.par_sort_unstable_by(|a, b| {
         let ord = b.meta.datetime.unwrap().cmp(&a.meta.datetime.unwrap());
         if ord == Ordering::Equal {
@@ -51,15 +46,14 @@ pub fn render_feeds(
     });
 
     let mut context = Context::new();
-    context.insert(
-        "last_updated",
-        pages
-            .iter()
-            .filter_map(|page| page.meta.updated.as_ref())
-            .chain(pages[0].meta.date.as_ref())
-            .max() // I love lexicographically sorted date strings
-            .unwrap(), // Guaranteed because of pages[0].meta.date
-    );
+    if let Some(last_updated) = pages
+        .iter()
+        .filter_map(|page| page.meta.updated.as_ref())
+        .chain(pages.first().and_then(|p| p.meta.date.as_ref()))
+        .max()
+    {
+        context.insert("last_updated", &last_updated);
+    }
     let library = site.library.read().unwrap();
     // limit to the last n elements if the limit is set; otherwise use all.
     let num_entries = site.config.feed_limit.unwrap_or(pages.len());
