@@ -2,7 +2,7 @@ use errors::{bail, Result};
 use libs::minify_html::{minify, Cfg};
 
 pub fn html(html: String) -> Result<String> {
-    let mut cfg = Cfg::spec_compliant();
+    let mut cfg = Cfg::new();
     cfg.keep_html_and_head_opening_tags = true;
     cfg.minify_css = true;
     cfg.minify_js = false;
