@@ -8,8 +8,8 @@ mod i18n;
 mod images;
 mod load_data;
 
-pub use self::content::{GetPage, GetSection, GetTaxonomy, GetTaxonomyUrl};
-pub use self::files::{GetFileHash, GetUrl};
+pub use self::content::{GetPage, GetSection, GetTaxonomy, GetTaxonomyTerm, GetTaxonomyUrl};
+pub use self::files::{GetHash, GetUrl};
 pub use self::i18n::Trans;
 pub use self::images::{GetImageMetadata, ResizeImage};
 pub use self::load_data::LoadData;
