@@ -10,9 +10,15 @@ fn anchor_id_checks(anchor: &str) -> Regex {
     Regex::new(&format!(r#"\s(?i)(id|name) *= *("|')*{}("|'| |>)+"#, escape(anchor))).unwrap()
 }
 
+/// Checks if anchor has a special meaning in HTML
+/// https://html.spec.whatwg.org/#select-the-indicated-part
+pub fn is_special_anchor(anchor: &str) -> bool {
+    anchor.is_empty() || anchor.eq_ignore_ascii_case("top")
+}
+
 #[cfg(test)]
 mod tests {
-    use super::anchor_id_checks;
+    use super::{anchor_id_checks, is_special_anchor};
 
     fn check(anchor: &str, content: &str) -> bool {
         anchor_id_checks(anchor).is_match(content)
@@ -52,4 +58,12 @@ id="fred">"#));
         // Non matchers
         assert!(!m(r#"<a notid="fred">"#));
     }
+
+    #[test]
+    fn test_is_special_anchor() {
+        assert!(is_special_anchor(""));
+        assert!(is_special_anchor("top"));
+        assert!(is_special_anchor("Top"));
+        assert!(!is_special_anchor("anchor"));
+    }
 }
