@@ -4,7 +4,7 @@ use libs::tera::{Context, Tera};
 
 use errors::{bail, Result};
 
-static DEFAULT_TPL: &str = include_str!("default_tpl.html");
+const DEFAULT_TPL: &str = include_str!("default_tpl.html");
 
 macro_rules! render_default_tpl {
     ($filename: expr, $url: expr) => {{
@@ -34,6 +34,24 @@ impl ShortcodeDefinition {
     }
 }
 
+#[derive(Debug, Default, Clone)]
+pub struct ShortcodeInvocationCounter {
+    amounts: HashMap<String, usize>,
+}
+impl ShortcodeInvocationCounter {
+    pub fn new() -> Self {
+        Self::default()
+    }
+    pub fn get(&mut self, str: &str) -> usize {
+        let nth = self.amounts.entry(str.into()).or_insert(0);
+        *nth += 1;
+        return *nth;
+    }
+    pub fn reset(&mut self) {
+        self.amounts.clear();
+    }
+}
+
 /// Fetches all the shortcodes from the Tera instances
 pub fn get_shortcodes(tera: &Tera) -> HashMap<String, ShortcodeDefinition> {
     let mut shortcode_definitions = HashMap::new();
@@ -186,7 +204,7 @@ mod tests {
         // Check finding existing template
         assert_eq!(check_template_fallbacks("index.html", &tera, &None), Some("index.html"));
 
-        // Check trying to find non-existant template
+        // Check trying to find non-existent template
         assert_eq!(check_template_fallbacks("not-here.html", &tera, &None), None);
 
         // Check theme fallback
